<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const page = usePage();
console.log(page.props);
const tax = computed(() => page.props.tax || []);
const shipping_price = computed(() => page.props.shipping_price || []);
const currency = computed(() => page.props.currency || []);

const form = useForm({
    shipping_price: shipping_price.value,
    tax: tax.value,
    currency: currency.value,
});

const flashMessage = ref('');

const submit = () => {
    form.post(route('admin.settings.update'), {
        onSuccess: () => {
            form.reset()
            flashMessage.value = "Settings saved successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};

onMounted(() => {

});
</script>

<template>

    <Head title="Settings" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Settings</h2>
        </template>

        <div class="py-12">

            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
                <form @submit.prevent="submit">
                    <div class="form-row px-8">

                        <div class="mt-4 col-md-12">
                            <InputLabel for="shipping_price" value="Shipping Price" />

                            <TextInput
                                id="shipping_price"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.shipping_price"
                                required
                                autofocus
                                autocomplete="shipping_price"
                            />

                            <InputError class="mt-2" :message="form.errors.shipping_price" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="tax" value="Tax (%)" />

                            <TextInput
                                id="tax"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.tax"
                                required
                                autofocus
                                autocomplete="tax"
                            />

                            <InputError class="mt-2" :message="form.errors.tax" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="currency" value="Currency" />

                            <TextInput
                                id="currency"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.currency"
                                required
                                autofocus
                                autocomplete="currency"
                            />

                            <InputError class="mt-2" :message="form.errors.currency" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start mt-4 col-md-12">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Save Settings
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
